#ifndef DETAILS_H
#define DETAILS_H

#include <QDialog>

namespace Ui {
    class Details;
}

class Details : public QDialog
{
    Q_OBJECT

public:
    explicit Details(QWidget *parent = 0);
    ~Details();

    Ui::Details *ui;

signals:
    void resizeWindow();

private:
    void closeEvent(QCloseEvent *e);

protected:
    void keyPressEvent(QKeyEvent *e);
    bool eventFilter(QObject *obj, QEvent *event);

};

#endif // DETAILS_H
